\name{metropolis}
\alias{metropolis}
\alias{metropolis.default}
\alias{metropolis.metropolis}
\title{Metropolis Algorithm}
\description{
    Markov chain Monte Carlo for continuous random vector using a Metropolis
    algorithm.
}
\usage{
metropolis(x, \dots)
metropolis.default(func, state, niter, env=environment(),
    control=list(scaling=1), ...)
metropolis.metropolis(o, niter)
}
\arguments{
  \item{func}{an R function that evaluates the unnormalized probability density
      of the desired equilibrium distribution of the Markov chain.  First
      argument is the state vector of the Markov chain.  Other arguments
      arbitrary.}
  \item{state}{a real vector, the initial state of the Markov chain.}
  \item{niter}{the number of iterations.}
  \item{env}{the environment for the function \code{func}.}
  \item{control}{A list of control parameters. See \bold{Details}.}
  \item{o}{an object of type "metropolis" from a preceding run.  In this
      form of the function call all arguments are taken from the \code{o}
      object except \code{niter}.}
}
\details{
Runs a "random-walk" Metropolis algorithm with multivariate normal proposal
producing a Markov chain with equilibrium distribution having a specified
unnormalized density.  Distribution must be continuous.  Support of the
distribution is the support of the density specified by argument \code{func}.
The initial state must satisfy \code{func(state, ...) > 0}.

  The \code{control} argument is a list that can supply any of the
  following components:
  \describe{
      \item{\code{scaling}}{controls the proposal step size.  If scalar or
          vector, the proposal is \code{x + scaling * z} where \code{x} is
          the current and \code{z} is a standard normal random vector.  If
          matrix, the proposal is \code{x + scaling \%*\% z}.}
    \item{\code{spacing}}{controls the subsampling of the Markov chain.
          A list
          with two components.  The value \code{list("constant", n)} where
          \code{n} is an integer uses every \code{n}-th iteration.
          The value \code{list("geometric", p)} where \code{0 <= p <= 1}
          uses spacings that are geometric random variables with parameter
          \code{p}.}
  }
}
\value{
  an object of class "metropolis", which is a list containing at
  least the following components:
  \item{accept}{fraction of Metropolis proposals accepted.}
  \item{path}{\code{length(state)} by \code{niter} matrix, the sample path.}
  \item{seed}{value of \code{.Random.seed} before the run.}
  \item{initial}{value of argument \code{state}, initial state of Markov chain.}
  \item{final}{final state of Markov chain, same as \code{path[ , niter]}.}
  \item{time}{running time of Markov chain from \code{system.time()}.}
  \item{control}{from input.}
  \item{density}{argument \code{func} from input.}
  \item{extra}{list containing all \code{...} arguments from input.}
  \item{env}{from input.}
}
\examples{
h <- function(x) if (all(x >= 0) && sum(x) <= 10) return(1) else return(0)
out <- metropolis(h, rep(0, 5), 10000)
out <- metropolis(out, 5000)
out$accept
plot(out$path[1, ])
hist(out$path[1, ])
}
\keyword{misc}
